//
//  WMStatusBar.m
//  UIWindowDemo
//
//  Created by wangmiao on 16/4/22.
//  Copyright © 2016年 wangmiao. All rights reserved.
//

#import "WMStatusBar.h"

@implementation WMStatusBar

static UIWindow *window_;
static NSTimer *timer_;


+ (void)showWindow
{
    CGFloat height = 20;
    CGRect frame = CGRectMake(0, - height, [UIScreen mainScreen].bounds.size.width, height);
    window_ = [[UIWindow alloc] init];
    window_.backgroundColor = [UIColor blackColor];
    // 让时间显示在window下面
    window_.windowLevel = UIWindowLevelAlert;
    window_.frame = frame;
    window_.hidden = NO;
    
    // 显示动画
    frame.origin.y = 0;
    [UIView animateWithDuration:0.25 animations:^{
        window_.frame = frame;
    }];
}

/**
 *  显示加载信息
 *
 *  @param message 加载信息
 *  @param image   提示图片
 */
+ (void)showMessage:(NSString *)message image:(UIImage *)image
{
    [timer_ invalidate];
    
    // 显示窗口
    [self showWindow];
    // 添加button，和image
    UIButton *button = [UIButton buttonWithType:UIButtonTypeCustom];
    button.frame = window_.bounds;
    [button setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    button.titleLabel.font = [UIFont systemFontOfSize:14];
    if (message) {
        [button setTitle:message forState:UIControlStateNormal];
    }
    if (image) {
        [button setImage:image forState:UIControlStateNormal];
    }
    [window_ addSubview:button];
    // repeats 设置为NO，不然timer制空也会在线程中调用hide
    timer_ = [NSTimer scheduledTimerWithTimeInterval:5 target:self selector:@selector(hide) userInfo:nil repeats:NO];
}

/**
 *  普通加载
 *
 *  @param message 加载信息
 */
+ (void)showMessage:(NSString *)message
{
    [self showMessage:message image:nil];
}

/**
 *  显示成功的信息
 *
 *  @param message 成功信息显示的内容
 */
+ (void)showSuccess:(NSString *)message
{
    [self showMessage:message image:[UIImage imageNamed:@"WMStatusBar.bundle/success"]];
    
}

/**
 *  显示失败的信息
 *
 *  @param message 失败信息显示的内容
 */
+ (void)showError:(NSString *)message
{
    [self showMessage:message image:[UIImage imageNamed:@"WMStatusBar.bundle/error"]];
}

/**
 *  正在加载
 *
 *  @param message 正在加载的信息
 */
+ (void)showLoading:(NSString *)message
{
    [timer_ invalidate];
    [self showWindow];
    
    UILabel *label = [[UILabel alloc] init];
    label.frame = window_.bounds;
    label.textAlignment = NSTextAlignmentCenter;
    label.text = message;
    label.textColor = [UIColor whiteColor];
    label.font = [UIFont systemFontOfSize:14];
    
    [window_ addSubview:label];
    
    UIActivityIndicatorView *loadingView = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhite];
    [loadingView startAnimating];
    
    
    CGFloat msgW = [message sizeWithAttributes:@{NSFontAttributeName:[UIFont systemFontOfSize:14]}].width;
    
    CGFloat centerX = (window_.frame.size.width - msgW) * 0.5 - 20;
    CGFloat centerY = window_.frame.size.height * 0.5;
    loadingView.center = CGPointMake(centerX, centerY);
    [window_ addSubview:loadingView];
}

+ (void)hide
{
    [UIView animateWithDuration:0.25 animations:^{
        // 结构体里修改frame
        CGRect frame = window_.frame;
        frame.origin.y = -window_.frame.origin.y;
        window_.frame = frame;
    } completion:^(BOOL finished) {
        window_ = nil;
        timer_ = nil;
        NSLog(@"%@", timer_);
    }];
}


@end
